/*
 * This file is part of LibNSLayout
 * Licensed under the ISC License, http://opensource.org/licenses/ISC
 * Copyright 2015 Michael Drake <tlsa@netsurf-browser.org>
 */

/** \file src/dom/watcher.h
 * Interface to DOM mutation watching.
 */

#ifndef nslayout_dom_watcher_h_
#define nslayout_dom_watcher_h_

#include <libnslayout/nslayout.h>

struct nsl_dom_watcher;

/**
 * Create DOM change watcher for a DOM document.
 *
 * \param[out]  watcher_out  Returns a dom watcher object for layout.
 * \param[in]   document     DOM document to create watcher for.
 * \return NSLAYOUT_OK on success, appropriate error otherwise.
 */
nslayout_error nsl_dom_watcher_create(
		struct nsl_dom_watcher **watcher_out,
		dom_document *document);

/**
 * Destroy a document change DOM change watcher.
 *
 * \param[in]  watcher  DOM change watcher to destroy.
 * \return NSLAYOUT_OK on success, appropriate error otherwise.
 */
nslayout_error nsl_dom_watcher_destroy(
		struct nsl_dom_watcher *watcher);

#endif
